pub enum AllowedAction {
ReadEntities,
ExtractStructuredData,
DraftCustomerMessage,
CreateInternalTask,
SuggestReservationStatus,
SuggestPlayEligibility,
SummarizeCareNotes,
FlagRisk,
}Expand description
Action an automation policy permits for a workflow outcome.
Variants
ReadEntities
Read entities workflow state, command, or review outcome.
ExtractStructuredData
Extract structured data workflow state, command, or review outcome.
DraftCustomerMessage
Draft customer message workflow state, command, or review outcome.
CreateInternalTask
Create internal task workflow state, command, or review outcome.
SuggestReservationStatus
Suggest reservation status workflow state, command, or review outcome.
SuggestPlayEligibility
Suggest play eligibility workflow state, command, or review outcome.
SummarizeCareNotes
Summarize care notes workflow state, command, or review outcome.
FlagRisk
Flag risk workflow state, command, or review outcome.